import { MessageHeader as AmqpMessageHeader } from "../rhea-promise";
/**
 * Describes the defined set of standard header properties of the message.
 * @interface MessageHeader
 */
export interface MessageHeader {
    /**
     * @property {boolean} [firstAcquirer] If this value is true, then this message has not been
     * acquired by any other link. Ifthis value is false, then this message MAY have previously
     * been acquired by another link or links.
     */
    firstAcquirer?: boolean;
    /**
     * @property {number} [deliveryCount] The number of prior unsuccessful delivery attempts.
     */
    deliveryCount?: number;
    /**
     * @property {number} [ttl] time to live in ms.
     */
    ttl?: number;
    /**
     * @property {boolean} [durable] Specifies durability requirements.
     */
    durable?: boolean;
    /**
     * @property {number} [priority] The relative message priority. Higher numbers indicate higher
     * priority messages.
     */
    priority?: number;
}
/**
 * Describes the operations that can be performed on the message header.
 * @module MessageHeader
 */
export declare namespace MessageHeader {
    /**
     * Converts MessageHeader to AmqpMessageHeader.
     *
     * @param {MessageHeader} props Message header.
     * @returns {AmqpMessageHeader} AmqpMessageHeader
     */
    function toAmqpMessageHeader(props: MessageHeader): AmqpMessageHeader;
    /**
     * Converts AmqpMessageHeader to MessageHeader.
     *
     * @param {AmqpMessageHeader} props Amqp Message Header
     * @returns {MessageHeader} MessageHeader.
     */
    function fromAmqpMessageProperties(props: AmqpMessageHeader): MessageHeader;
}
